pub struct EventuallyConsistentStoreExtension<S>where
S: Storage,{ /* private fields */ }Expand description
A fully managed eventually consistent state controller.
The EventuallyConsistentStore manages all RPC and state propagation for a given application, where the only setup required is the RPC based configuration and the required handler traits which wrap the application itself.
Datacake essentially acts as a frontend wrapper around a datastore to make is distributed.
Implementations
Sourceimpl<S> EventuallyConsistentStoreExtension<S>where
S: Storage,
impl<S> EventuallyConsistentStoreExtension<S>where
S: Storage,
Sourcepub fn new(store: S) -> Self
pub fn new(store: S) -> Self
Creates a new extension with a given data store, using the default repair interval.
Sourcepub fn with_repair_interval(self, dur: Duration) -> Self
pub fn with_repair_interval(self, dur: Duration) -> Self
Set a custom repair interval rather than the default (1 hour.)