pub struct ReplicatedStoreHandle<S>where
S: Storage,{ /* private fields */ }Expand description
A cheaply cloneable handle to control the data store.
Implementations
Sourceimpl<S> ReplicatedStoreHandle<S>where
S: Storage,
impl<S> ReplicatedStoreHandle<S>where
S: Storage,
Sourcepub fn statistics(&self) -> &SystemStatistics
pub fn statistics(&self) -> &SystemStatistics
Gets the live cluster statistics.
Sourcepub fn with_keyspace(
&self,
keyspace: impl Into<String>,
) -> ReplicatorKeyspaceHandle<S>
pub fn with_keyspace( &self, keyspace: impl Into<String>, ) -> ReplicatorKeyspaceHandle<S>
Creates a new handle to the underlying storage system with a preset keyspace.
Changes applied to the handle are distributed across the cluster.
Sourcepub async fn get(
&self,
keyspace: &str,
doc_id: Key,
) -> Result<Option<Document>, S::Error>
pub async fn get( &self, keyspace: &str, doc_id: Key, ) -> Result<Option<Document>, S::Error>
Retrieves a document from the underlying storage.
Sourcepub async fn get_many<I, T>(
&self,
keyspace: &str,
doc_ids: I,
) -> Result<S::DocsIter, S::Error>
pub async fn get_many<I, T>( &self, keyspace: &str, doc_ids: I, ) -> Result<S::DocsIter, S::Error>
Retrieves a set of documents from the underlying storage.
If a document does not exist with the given ID, it is simply not part of the returned iterator.
Sourcepub async fn put<D>(
&self,
keyspace: &str,
doc_id: Key,
data: D,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn put<D>( &self, keyspace: &str, doc_id: Key, data: D, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Insert or update a single document into the datastore.
Sourcepub async fn put_many<I, T, D>(
&self,
keyspace: &str,
documents: I,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn put_many<I, T, D>( &self, keyspace: &str, documents: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Insert or update multiple documents into the datastore at once.
Sourcepub async fn del(
&self,
keyspace: &str,
doc_id: Key,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn del( &self, keyspace: &str, doc_id: Key, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Delete a document from the datastore with a given doc ID.
Sourcepub async fn del_many<I, T>(
&self,
keyspace: &str,
doc_ids: I,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn del_many<I, T>( &self, keyspace: &str, doc_ids: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Delete multiple documents from the datastore from the set of doc IDs.