ReplicatorKeyspaceHandle

Struct ReplicatorKeyspaceHandle 

pub struct ReplicatorKeyspaceHandle<S>
where S: Storage,
{ /* private fields */ }
A convenience wrapper which creates a new handle with a preset keyspace.

Implementations

Source

impl<S> ReplicatorKeyspaceHandle<S>
where S: Storage,

pub async fn get(&self, doc_id: Key) -> Result<Option<Document>, S::Error>

Retrieves a document from the underlying storage.

pub async fn get_many<I, T>(&self, doc_ids: I) -> Result<S::DocsIter, S::Error>
where T: Iterator<Item = Key> + Send, I: IntoIterator<IntoIter = T> + Send,

Retrieves a set of documents from the underlying storage.

If a document does not exist with the given ID, it is simply not part of the returned iterator.

pub async fn put( &self, doc_id: Key, data: Vec<u8>, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>

Insert or update a single document into the datastore.

pub async fn put_many<I, T>( &self, documents: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
where T: Iterator<Item = (Key, Vec<u8>)> + Send, I: IntoIterator<IntoIter = T> + Send,

Insert or update multiple documents into the datastore at once.

pub async fn del( &self, doc_id: Key, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>

Delete a document from the datastore with a given doc ID.

pub async fn del_many<I, T>( &self, doc_ids: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
where T: Iterator<Item = Key> + Send, I: IntoIterator<IntoIter = T> + Send,

Delete multiple documents from the datastore from the set of doc IDs.