pub enum StoreError<E: Error + Send + 'static> {
ChitChatError(String),
UnknownError(Error),
StorageError(E),
BulkStorageError(BulkMutationError<E>),
ConsistencyError(ConsistencyError),
TransportError(SocketAddr, Error),
RpcError(SocketAddr, Status),
}Expand description
A wrapping error for the store which can potentially fail under situations.
Variants
ChitChatError(String)
An error has occurred within Chitchat.
UnknownError(Error)
An error has occurred which datacake was not expecting nad from an unknown source.
StorageError(E)
A failure has occurred within the provided storage system causing the operation to fail.
BulkStorageError(BulkMutationError<E>)
A failure has occurred within the provided storage system causing the operation to fail.
This error however, includes the set of doc ids which were successfully completed, this can be used to maintain partial and incremental updates despite and error, otherwise bulk storage operations must be entirely atomic if they do not specify the successful IDs.
ConsistencyError(ConsistencyError)
The operation succeeded on the local node but failed to meet the required consistency level within the timeout period. (2 seconds)
TransportError(SocketAddr, Error)
An error occurred when attempting to open a connection or listen on a given address.
RpcError(SocketAddr, Status)
An error occurred during RPC communication with other nodes.