pub struct EventuallyConsistentStore<S>where
S: Storage,{ /* private fields */ }Expand description
A fully managed eventually consistent state controller.
The EventuallyConsistentStore manages all RPC and state propagation for a given application, where the only setup required is the RPC based configuration and the required handler traits which wrap the application itself.
Datacake essentially acts as a frontend wrapper around a datastore to make is distributed.
Implementations
Sourceimpl<S> EventuallyConsistentStore<S>where
S: Storage,
impl<S> EventuallyConsistentStore<S>where
S: Storage,
Sourcepub fn statistics(&self) -> &SystemStatistics
pub fn statistics(&self) -> &SystemStatistics
Gets the live cluster statistics.
Sourcepub fn handle(&self) -> ReplicatedStoreHandle<S>
pub fn handle(&self) -> ReplicatedStoreHandle<S>
Creates a new handle to the underlying storage system.
Changes applied to the handle are distributed across the cluster.
Sourcepub fn handle_with_keyspace(
&self,
keyspace: impl Into<String>,
) -> ReplicatorKeyspaceHandle<S>
pub fn handle_with_keyspace( &self, keyspace: impl Into<String>, ) -> ReplicatorKeyspaceHandle<S>
Creates a new handle to the underlying storage system with a preset keyspace.
Changes applied to the handle are distributed across the cluster.