pub struct ReplicatorKeyspaceHandle<S>where
S: Storage,{ /* private fields */ }Expand description
A convenience wrapper which creates a new handle with a preset keyspace.
Implementations
Sourceimpl<S> ReplicatorKeyspaceHandle<S>where
S: Storage,
impl<S> ReplicatorKeyspaceHandle<S>where
S: Storage,
Sourcepub async fn get(&self, doc_id: Key) -> Result<Option<Document>, S::Error>
pub async fn get(&self, doc_id: Key) -> Result<Option<Document>, S::Error>
Retrieves a document from the underlying storage.
Sourcepub async fn get_many<I, T>(&self, doc_ids: I) -> Result<S::DocsIter, S::Error>
pub async fn get_many<I, T>(&self, doc_ids: I) -> Result<S::DocsIter, S::Error>
Retrieves a set of documents from the underlying storage.
If a document does not exist with the given ID, it is simply not part of the returned iterator.
Sourcepub async fn put(
&self,
doc_id: Key,
data: Vec<u8>,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn put( &self, doc_id: Key, data: Vec<u8>, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Insert or update a single document into the datastore.
Sourcepub async fn put_many<I, T>(
&self,
documents: I,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn put_many<I, T>( &self, documents: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Insert or update multiple documents into the datastore at once.
Sourcepub async fn del(
&self,
doc_id: Key,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn del( &self, doc_id: Key, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Delete a document from the datastore with a given doc ID.
Sourcepub async fn del_many<I, T>(
&self,
doc_ids: I,
consistency: Consistency,
) -> Result<(), StoreError<S::Error>>
pub async fn del_many<I, T>( &self, doc_ids: I, consistency: Consistency, ) -> Result<(), StoreError<S::Error>>
Delete multiple documents from the datastore from the set of doc IDs.